@@ -1,8 +1,8 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 
 ## system-config-printer
 
-## Copyright (C) 2010, 2011, 2012, 2013 Red Hat, Inc.
+## Copyright (C) 2010, 2011, 2012, 2013, 2014 Red Hat, Inc.
 ## Author: Tim Waugh <twaugh@redhat.com>
 
 ## This program is free software; you can redistribute it and/or modify
@@ -31,7 +31,7 @@ import asyncconn
 from debug import debugprint
 import config
 import gettext
-gettext.install(domain=config.PACKAGE, localedir=config.localedir, unicode=True)
+gettext.install(domain=config.PACKAGE, localedir=config.localedir)
 
 class PPDsLoader(GObject.GObject):
     """
@@ -50,7 +50,7 @@ class PPDsLoader(GObject.GObject):
     """
 
     __gsignals__ = {
-        'finished': (GObject.SIGNAL_RUN_LAST, None, ())
+        'finished': (GObject.SignalFlags.RUN_LAST, None, ())
         }
 
     def __init__ (self, device_id=None, parent=None, device_uri=None,
@@ -74,7 +74,7 @@ class PPDsLoader(GObject.GObject):
         self._ppdsmatch_result = None
         self._jockey_queried = False
         self._jockey_has_answered = False
-        self._local_cups = (self._host == None or
+        self._local_cups = (self._host is None or
                             self._host == "localhost" or
                             self._host[0] == '/')
         try:
@@ -100,7 +100,11 @@ class PPDsLoader(GObject.GObject):
         if self._device_id:
             self._devid_dict = cupshelpers.parseDeviceID (self._device_id)
 
-        if self._local_cups and self._device_id and self._bus:
+        if (self._local_cups and
+            self._device_id and
+            self._devid_dict["MFG"] and
+            self._devid_dict["MDL"] and
+            self._bus):
             self._gpk_device_id = "MFG:%s;MDL:%s;" % (self._devid_dict["MFG"],
                                                       self._devid_dict["MDL"])
             self._query_packagekit ()
@@ -170,7 +174,7 @@ class PPDsLoader(GObject.GObject):
                                          self._device_make_and_model)
 
             ppdnamelist = ppds.\
-                orderPPDNamesByPreference (fit.keys (),
+                orderPPDNamesByPreference (list(fit.keys ()),
                                            self._installed_files,
                                            devid=self._devid_dict,
                                            fit=fit)
@@ -180,6 +184,8 @@ class PPDsLoader(GObject.GObject):
             if (self._bus and
                 not fit[ppdname].startswith ("exact") and
                 not self._jockey_queried and
+                self._devid_dict["MFG"] and
+                self._devid_dict["MDL"] and
                 self._local_cups):
                 # Try to install packages using jockey if
                 # - there's no appropriate driver (PPD) locally available
@@ -190,7 +196,7 @@ class PPDsLoader(GObject.GObject):
 
         conn.destroy ()
         self._conn = None
-        if self._dialog != None:
+        if self._dialog is not None:
             self._dialog.destroy ()
             self._dialog = None
 
@@ -201,7 +207,7 @@ class PPDsLoader(GObject.GObject):
         self._conn = None
         self._ppds = None
         self._exc = exc
-        if self._dialog != None:
+        if self._dialog is not None:
             self._dialog.destroy ()
             self._dialog = None
 
@@ -267,11 +273,11 @@ class PPDsLoader(GObject.GObject):
         if self._need_requery_cups:
             self._query_cups ()
         else:
-            if self._conn != None:
+            if self._conn is not None:
                 self._conn.destroy ()
                 self._conn = None
 
-            if self._dialog != None:
+            if self._dialog is not None:
                 self._dialog.destroy ()
                 self._dialog = None
 
@@ -298,10 +304,10 @@ if __name__ == "__main__":
             self._window.destroy ()
             Gtk.main_quit ()
             exc = ppdsloader.get_error ()
-            print exc
+            print(exc)
             ppds = ppdsloader.get_ppds ()
-            if ppds != None:
-                print len (ppds)
+            if ppds is not None:
+                print(len (ppds))
 
             ppdsloader.destroy ()
 
