@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 
 ## Copyright (C) 2007, 2008, 2009, 2010, 2012, 2013, 2014 Red Hat, Inc.
 ## Authors:
@@ -23,7 +23,7 @@ import cups
 import os
 import config
 import gettext
-gettext.install(domain=config.PACKAGE, localedir=config.localedir, unicode=True)
+gettext.install(domain=config.PACKAGE, localedir=config.localedir)
 
 class StateReason:
     REPORT=1
@@ -31,9 +31,9 @@ class StateReason:
     ERROR=3
 
     LEVEL_ICON={
-        REPORT: "gtk-dialog-info",
-        WARNING: "gtk-dialog-warning",
-        ERROR: "gtk-dialog-error"
+        REPORT: "dialog-information",
+        WARNING: "dialog-warning",
+        ERROR: "dialog-error"
         }
 
     def __init__(self, printer, reason, ppdcache=None):
@@ -52,7 +52,7 @@ class StateReason:
         return self.printer
 
     def get_level (self):
-        if self.level != None:
+        if self.level is not None:
             return self.level
 
         if (self.reason.endswith ("-report") or
@@ -156,7 +156,7 @@ class StateReason:
                     for scheme in schemes:
                         lreason = self._ppd.localizeIPPReason(self.reason,
                                                               scheme)
-                        if lreason != None:
+                        if lreason is not None:
                             localized_reason = localized_reason + lreason + ", "
                     if localized_reason != "":
                         reason = localized_reason[:-2]
@@ -169,11 +169,12 @@ class StateReason:
     def get_tuple (self):
         return (self.get_level (), self.get_printer (), self.get_reason ())
 
-    def __cmp__(self, other):
-        if other == None:
-            return 1
-        if other.get_level () != self.get_level ():
-            return cmp (self.get_level (), other.get_level ())
-        if other.get_printer () != self.get_printer ():
-            return cmp (other.get_printer (), self.get_printer ())
-        return cmp (other.get_reason (), self.get_reason ())
+    def __eq__(self, other):
+      if type (other) != type (self):
+            return False
+      return self.get_level () == other.get_level ()
+
+    def __lt__(self, other):
+      if type (other) != type (self):
+            return False
+      return self.get_level () < other.get_level ()
